# Stripboardmixer

A simple 3-Channel stripboardmixer with master volume. The mixer is DC-coupled, that means it can be used both with Audio and CV signals.  

The circuit works as a simple inverting summing stage with another inverting amplifier to buffer the output of the master attenuator and flip the signal back to normal. Check out [the simulation here](http://falstad.com/circuit/circuitjs.html?cct=$+1+0.000005+16.817414165184545+50+5+43%0AR+-48+80+-96+80+0+1+40+5+0+0+0.5%0A174+-48+144+-16+80+0+100000+0.9950000000000001+Input+1%0Ag+-48+144+-48+160+0%0Ar+-16+112+64+112+0+100000%0Ar+-16+224+64+224+0+100000%0Ag+-48+256+-48+272+0%0A174+-48+256+-16+208+0+100000+0.9950000000000001+Input+2%0AR+-48+192+-96+192+0+3+40+5+0+0+0.5%0AR+-48+304+-96+304+0+2+40+5+0+0+0.25%0A174+-48+368+-16+320+0+100000+0.9950000000000001+Input+3%0Ag+-48+368+-48+384+0%0Ar+-16+336+64+336+0+100000%0Aw+64+336+64+224+0%0Aw+64+224+64+112+0%0Aa+128+240+208+240+0+15+-15+1000000+-0.00006929447617044292+0%0Aw+128+224+64+224+0%0Ag+128+256+128+304+0%0Ar+128+176+208+176+0+100000%0Aw+208+176+208+240+0%0Aw+128+176+128+224+0%0A174+240+304+288+256+0+100000+0.9950000000000001+Master%0Ag+240+304+240+320+0%0Aw+240+240+208+240+0%0Aa+336+288+432+288+0+15+-15+1000000+0.00010290746324849728+0%0Ag+336+304+336+320+0%0Ar+336+272+288+272+0+100000%0Ar+336+224+432+224+0+150000%0Aw+336+272+336+224+0%0Aw+432+288+432+224+0%0AO+432+288+496+288+0%0Ax+141+13+310+16+6+24+Stripboardmixer%0Ax+-51+36+58+69+4+12+3%5CsChannels%5Cscan%5Csbe%5C%5Cnmixed/summed%5Csinto%5C%5Cnone%5Csoutput%0Ax+227+204+304+222+4+12+Master%5C%5CnPotentiometer%0Ax+292+105+536+168+4+12+The%5Csrelationship%5Csbetween%5Csthe%5Cs100k%5Csresistor%5C%5Cnat%5Csthe%5Csinverting%5Csinput%5Csand%5Csthis%5Cs150k%5Csresistor%5C%5Cndetermines%5Csthe%5Csgain%5Csof%5Csthe%5Cscircuit:%5C%5CnIf%5Csboth%5Csare%5Cs100k%5Cswe%5Csget%5Csa%5Csmaximum%5Csgain%5Csof%5Cs1,%5C%5Cnthe%5Csfeedback%5Csresistor%5Csis%5Cs150k%5Csthe%5Csgain%5Csis%5Cs1.5%0Ao+0+64+0+4098+5+0.00009765625+0+2+0+3%0Ao+7+64+0+4098+5+0.00009765625+0+2+7+3%0Ao+8+64+0+4098+5+0.00009765625+0+2+8+3%0Ao+29+64+0+4098+20+0.1+0+1%0A). 

![images/schematic_mixer.png](images/schematic_mixer.png)  

![images/schematic_power.png](images/schematic_power.png)  

## Stripboard Layout

### 1. Cut board to right size (100x30mm or 39x11 holes)
<img src="images/board.png" height="800px" width="auto" />  

### 2. Cut away the right traces and solder in the parts

Avoid mistakes here at all cost! Be careful and take your time, especially for the traces between the legs of the potentiometers! Do not try to be fast here, it will bite you later on! Make sure to get the positions of the parts exactly right – otherwise things might not work and you have to figure out a panel layout yourself!  

<img src="images/scratch_away_parts.png" height="800px" width="auto" />  
  
Also:  
- Drill 2mm holes for the mechanical legs of the potentiometers
- Make sure to get the orientation of the Diodes (BAT-42, orange in the picture – the stripe is up), the big electrolytic capacitors and the socket for the chip right (leave the chip out of the socket until the end)
- Make sure to solder the 2x5 pin power header (on bottom) last
- Keep the clipped away legs for later

### 3. Solder short bridges on bottom
Use the clipped away legs or enough solder to bridge the marked parts on the bottom:  

<img src="images/bottom_bridges.png" height="800px" width="auto" />  

### 4. Add Cable Connections (both top and bottom)

Make sure blank parts of the cable don't touch anything else. Take it easy and go slow.

<img src="images/all.png" height="800px" width="auto" />  

### 5. Testing
- Measure Ground and power connections with a multimeter in beep-mode from the middle pin of the powerheader to every pin that should have ground according to the schematic
- Test the circuit's power consumption without a chip using two lab power supplies. If it draws more than 5mA there is probably a short circuit
- Finally insert the chip and test the circuits power consumption again
- Test the mixer with a function generator and a oscilloscope

### 6. Panel

<img src="images/panel.png" height="800px" width="auto" />    


## Mods
### 1. Gain Mod
Increase the gain of the whole circuit to allow louder output.  

![](images/gain_mod.png)  

Replace `R6` to get the desired gain. To calculate the total gain calculate: `R6/R5` . For the original circuit with R5 and R6 both beeing 100k this formula equals to a gain of 1.0. A gain of 1 is also called _unity gain_. This means the input has the same level as the output at maximum level. So if you connect 1V at `INPUT1` and turn up all the dials, with unity gain you will get 1V at the output. Because we are summing the inputs in `U1A` this means that if we input 1V at `INPUT1`, `INPUT2` and `INPUT3` and turn all the dials to 100%, we will get 3V on `OUT`.  

If we set `R6` to 150k, we calculate the formula `150k/100k` we get a gain of 1.5

If we set `R6` to 50k, we calculate the formula `50k/100k` we get a gain of 0.5

### 2. Input Gain Mod

If you want to input stuff frome line level devices (e.g. a smartphone, a laptop etc.) you can mod one of the channels to be more sensitive. 

![](images/line_mod.png)



The voltages of a modular synthesizer are ±5V or 10V peak to peak – [comsumer line level](https://en.wikipedia.org/wiki/Line_level) is 0.894V peak to peak. This means to get a consumer line level signal to 10Vpp we need a gain of `10Vpp / 0.894Vpp = ~11,19`.

To get that gain value we have to change one of the input's resistor (let's say `R3`) to match the formula `gain = R4/R3`. If we move the formula around we end up with `R3 = R4/gain`. With values inserted: `R3 = 100k/11.19` and this yields a value of `8.93k` for `R3`. The next lowervalue in the resistor series is `8.87k` which yields a gain of `11.27` – close enough!



### 3. Distortion Mod

If you don't need a mixer, but want to use this module as some kind of effects module you can mode it with diodes.



(Work in Progress)

